@@ -4,30 +4,29 @@
 #	 into one of several formats suitable for viewing on a Palm
 #	 handheld.
 #
-# Skip down to read the POD documentation, or search for "=head1".
-#
 # Sitescooper is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
 # Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.  See the COPYRIGHT section in the POD
 # documentation below, or the "doc/gpl.html" file in the distribution,
 # for further details.
+#
+# Skip down to read the POD documentation, or search for "=head1".
 
 #---------------------------------------------------------------------------
 
 # Mac users -- you can pass in command-line arguments, such as "-isilo"
 # or "-refresh", by changing this line. These will be prepended to the
 # names of any documents you drag and drop onto sitescooper.
+# Another way to do this is by creating a .scp config file with the
+# CommandLine: parameter in it, and double-clicking it to run sitescooper.
 #
-$Scoop::MAC_ARGS = "";
-
-# the default configuration has now moved to the "sitescooper.cf" file,
-# in the directory you installed sitescooper. On UNIX platforms this
-# will be copied to your home directory so you can also edit it there.
+$MAC_ARGS = "";
 
 #---------------------------------------------------------------------------
 
-sub usage { die <<__ENDOFUSAGE;
+sub usage {
+  die <<__ENDOFUSAGE;
 
 Sitescooper - download news from web sites and convert it automatically
 	into one of several formats suitable for viewing on a Palm
@@ -38,90 +37,287 @@ sitescooper [options] [ [-site sitename] ...]
 sitescooper [options] [-sites sitename ...]
 
 sitescooper [options] [-name nm] [-levels n] [-storyurl regexp]
-	[-set sitefileparam value] url [...]
+  [-set sitefileparam value] url [...]
 
-Options: [-debug] [-refresh] [-config file]
-	[-install dir] [-instapp app] [-dump] [-dumpprc] [-nowrite]
-	[-nodates] [-quiet] [-admin cmd] [-nolinkrewrite] [-stdout-to file]
-	[-keep-tmps] [-noheaders] [-nofooters] [-fromcache]
-	[-filename template] [-prctitle template] [-parallel] [-disc]
-	[-limit numkbytes] [-maxlinks numlinks] [-maxstories numstories]
-	[-text | -html | -mhtml | -doc | -isilo | -misilo | -richreader
-	| -pipe fmt command]
+Options: [-debug] [-refresh] [-fullrefresh] [-config file]
+  [-install dir] [-instapp app] [-dump] [-dumpprc] [-nowrite]
+  [-nodates] [-quiet] [-admin cmd] [-stdout-to file]
+  [-keep-tmps] [-fromcache] [-noheaders] [-nofooters] [-badcache]
+  [-outputtemplate file.tmpl]
+  [-filename template] [-prctitle template] [-parallel] [-disc]
+  [-limit numkbytes] [-maxlinks numlinks] [-maxstories numstories]
+
+  [-text | -html | -mhtml | -doc | -plucker | -mplucker | -isilo
+  | -misilo | -richreader | -pipe fmt command]
+  [-bw | -color] [-maxcolors n] [-fixlinks | -keeplinks | -nolinkrewrite]
+  [-cvtargs args_for_converter]
 
 file:// and http:// URLs are supported.
 
-Version: $Scoop::VERSION
+Version: $Sitescooper::Main::VERSION
 __ENDOFUSAGE
 								    }
 
+use strict;
+use FindBin;
+
+use vars qw{
+  	$MAC_ARGS $SLASH
+};
+
 $SIG{__WARN__} = 'warn_log';
 $SIG{__DIE__} = 'die_log';
 
-use FindBin;
-
 BEGIN {
-  # sadly, we can't rely on File::Spec to do this for us. It's not
-  # included with some versions of MacPerl.
+  # This code will track down the directories where sitescooper
+  # keeps its modules, portably, so it'll work on Macs, UNIX and Win32.
+  # Sadly, we can't rely on File::Spec to do the slash-twiddling for us;
+  # it's not included with some versions of MacPerl. :(
   #
+  my $bin = $FindBin::Bin;
+  my $slash = '/';		# between directories in a path
+  my $dirtrailer = '';		# at the end of a directory's path
+
   if ($^O eq 'MacOS') {
-    $_ = $FindBin::Bin; s/:$//;
-    use lib $FindBin::Bin . ":lib:";
-    use lib $FindBin::Bin . "::lib:sitescooper:lib:";
-    use lib $FindBin::Bin . "::share:sitescooper:lib:";
-
+    $slash = ':'; $dirtrailer = ':';
   } elsif ($^O =~ /(win|os2)/) {
-    use lib $FindBin::Bin . "\\lib";
-    use lib $FindBin::Bin . "\\..\\lib\\sitescooper\\lib";
-    use lib $FindBin::Bin . "\\..\\share\\sitescooper\\lib";
+    $slash = '\\';
+  }
 
-  } else {
-    use lib $FindBin::Bin . "/lib";
-    use lib $FindBin::Bin . "/../lib/sitescooper/lib";
-    use lib $FindBin::Bin . "/../share/sitescooper/lib";
+  # first, find the common candidates: "lib" and "site_perl" in
+  # the same dir as the script. These are likely on all platforms.
+  # Note that we use push for all modules; the sitescooper ones
+  # will not be installed, and the LWP ones should use the local
+  # copies anyway as some of them (HTML::Parser for example) will
+  # be able to use XS code which is faster.
+  $_ = $bin.$slash. "lib" . $dirtrailer;
+  push (@INC, $_);
+  $_ = $bin.$slash. "site_perl" . $dirtrailer;
+  push (@INC, $_);
+
+  # next, support UNIX-style /usr-based installation, where the
+  # script lives in /usr/*/bin and the support files in /usr/*/lib
+  # or /usr/*/share. This only happens on UNIX afaik.
+  if ($slash eq '/') {
+    $_ = $bin . "/../lib/sitescooper";
+    if (-d $_) {
+      push (@INC, $_); push (@INC, "$_/lib"); push (@INC, "$_/site_perl");
+    }
+
+    $_ = $bin . "/../share/sitescooper";
+    if (-d $_) {
+      push (@INC, $_); push (@INC, "$_/lib"); push (@INC, "$_/site_perl");
+    }
   }
 }
 
-# CUSTOMISE: you may need to add 'use "your_lib_dir";' here
+# CUSTOMISE: you may need to add 'use lib "your_lib_dir";' here
+
+use File::Copy;
+use Sitescooper::Main;
+
+my $ui = new Sitescooper::CmdlineUI();
+
+my $scoop = new Sitescooper::Main($ui);
+my $system_config = '';
+my $config = '';
+
+$SLASH = $Sitescooper::Main::SLASH;
+
+# Mac support for command-line args.
+my @macargs = split (' ', $MAC_ARGS);
+unshift (@ARGV, @macargs);
+$MAC_ARGS = '';
+
+# parse args, and use the -config argument if set.
+$scoop->parse_commandline (@ARGV);
+if (defined $scoop->{cf}->{config}) { $config = $scoop->{cf}->{config}; }
+
+# once-off: migrate the old tmp files to their new locations.
+migrate_user_tmp_files();
+
+# set the paths for state directories and config files.
+if (Sitescooper::Main::MyOS() eq 'UNIX') {
+  $scoop->set_tmp_dir ("~/.sitescooper");
+  $scoop->make_basic_dirs();     # make tmpdir first off
+
+  $system_config = $scoop->get_first_existing_path
+  			("/etc/sitescooper.cf",
+  			"/etc/sitescooper/sitescooper.cf",
+  			"/opt/etc/sitescooper.cf",
+  			"/opt/etc/sitescooper/sitescooper.cf",
+  			"/usr/local/etc/sitescooper.cf",
+  			"/usr/local/etc/sitescooper/sitescooper.cf",
+			"%S/sitescooper.cf");
+
+  $config ||= $scoop->sed_path ("~/.sitescooper/sitescooper.cf");
+  create_home_cf_if_needed($config);
+
+} else {
+  $scoop->set_tmp_dir ("%S/tmp");
+  $scoop->make_basic_dirs();     # make tmpdir first off
+  $system_config = $scoop->sed_path ("%S/sitescooper.cf");
+  $config ||= $scoop->sed_path ("%S/sitescooper.cf");
+}
+
+# read the configuration. (note: do not use %T until interpret_basic_config() is
+# called!)
+#
+$scoop->verbose ("Reading configuration from \"$config\".");
+open (IN, "<$config") or die "cannot read \"$config\"\n";
+my @conf = (<IN>);
+close IN;
+$scoop->read_config ($config, @conf);
+$scoop->interpret_basic_config();
+$scoop->load_all_modules();
+
+# this has to be here after reading the config; config may change setting
+# of the %S escape.
+#
+if (!defined $scoop->{cf}->{mysitesdir}) {
+  if (Sitescooper::Main::MyOS() eq 'UNIX') {
+    $scoop->set_my_sites_dir ("sites", "~/sites", "%T/sites");
+  } else {
+    $scoop->set_my_sites_dir ("sites", "%S/sites", "%T/sites");
+  }
+}
+$scoop->set_shared_sites_dir ("%S/share/site_samples", "%S/site_samples");
+$scoop->set_site_choices_file ("%T/site_choices.txt");
+
+# set the interface used to ask for site passwords
+#
+my $asker = new Sitescooper::ConsolePasswordAsker($scoop);
+$scoop->{useragent}->set_password_asker ($asker);
+
+# see where to save PDB files
+#
+if (!defined $scoop->{cf}->{pilotinstdir}
+      && !defined $scoop->{cf}->{pilotinstapp})
+{
+  # write PDBs to cwd if nothing is set.
+  $scoop->verbose ("Warning: since no PilotInstallDir was specified".
+  " in the configuration,\nPDB files will be saved to current directory.\n");
+  $scoop->parse_commandline ('-install', $scoop->{cwd});
+}
+
+$scoop->read_site_choices();
+$scoop->find_sites_in_sites_dir();
+$scoop->read_site_files();
+$scoop->read_newshound_profiles();
+$scoop->read_commandline_scoops();
+
+$scoop->get_ready_for_run ();
+$scoop->run ();
+$scoop->finish ();
+$ui->cleanexit ();
+
+#---------------------------------------------------------------------------
+
+sub migrate_user_tmp_files {
+  my ($tmp, $oldtmp, $newtmp, $usertmp);
+
+  if (Sitescooper::Main::MyOS() eq 'UNIX') {
+    $oldtmp = $scoop->sed_path ("~/.sitescooper");
+    $usertmp = $scoop->sed_path ("~/.sitescooper/sitescooper_$<");
+    $newtmp = $scoop->sed_path ("~/.sitescooper");
+
+  } else {
+    $oldtmp = $scoop->sed_path ("%t");
+    $usertmp = $scoop->sed_path ("%t/sitescooper_$<");
+    $newtmp = $scoop->sed_path ("%S/tmp");
+  }
+
+  if (-e $usertmp.$SLASH."already_seen.txt") {
+    for my $item (qw(cookies txt cache already_seen.txt
+			   prc sites inst.txt site_logins))
+    {
+      my $old = "$usertmp$SLASH$item";
+      my $new = "$newtmp$SLASH$item";
+
+      if ($old ne $new && -e $old) {
+	warn "Migrating $old to: $new\n";
+	move ($old, $new) or warn "Failed to rename $old to $new\n";
+      }
+    }
+
+    for my $item (qw(site_choices.txt))
+    {
+      my $old = "$oldtmp$SLASH$item";
+      my $new = "$newtmp$SLASH$item";
+
+      if ($old ne $new && -e $old) {
+	warn "Migrating $old to: $new\n";
+	move ($old, $new) or warn "Failed to rename $old to $new\n";
+      }
+    }
+  }
+}
+
+sub create_home_cf_if_needed {
+  my $homecf = shift;
+  if (!-e $homecf) {
+    warn "Copying default config to \"$homecf\".\n".
+        "Edit this if you need to change any configuration settings.\n\n";
+    copy ($system_config, $homecf) or
+	       die "cannot copy $system_config to $homecf\n";
+  }
+}
 
-use Scoop;
-&Scoop::Init;
-&Scoop::ParseArgs;
-&Scoop::ReadConfig;
-&Scoop::ReadSites;
-&Scoop::Run;
-&Scoop::Finish;
-&cleanexit;
 
 # ---------------------------------------------------------------------------
+# User interface for command-line use. Override for GUIs, mod_perl use, etc.
+
+package Sitescooper::CmdlineUI;
+use Sitescooper::UI;
+
+BEGIN {
+  @Sitescooper::CmdlineUI::ISA = qw(Sitescooper::UI);
+}
+
+sub new {
+  my ($class) = shift; $class = ref($class) || $class;
+  my $self = $class->SUPER::new();
+  $self;
+}
+
+sub usage {
+  my ($self) = @_; main::usage();
+}
 
 sub scoop_die {
-  print STDERR @_; &cleanexit(2);
+  my ($self, @msg) = @_;
+  print STDERR @msg; $self->cleanexit(2);
 }
 
 sub scoop_warn {
-  print STDERR @_;
+  my ($self, @msg) = @_;
+  print STDERR @msg;
 }
 
 sub dbg {
-  print STDERR "debug: ",@_,"\n";
+  my ($self, @msg) = @_;
+  print STDERR "debug: ",@msg,"\n";
 }
 
 sub sitewarn {
-  my $fname = shift;
-  warn "Site \"$fname\": ".join('', @_)."\n";
+  my ($self, $fname, @msg) = @_;
+  warn "SITE WARNING: $fname: ".join('', @msg)."\n";
 }
 sub verbose {
-  print STDERR @_,"\n";
+  my ($self, @msg) = @_;
+  print STDERR @msg,"\n";
 }
 
 sub cleanexit {
+  my ($self) = @_;
+  shift;
   $SIG{__WARN__} = '';
   $SIG{__DIE__} = '';
   exit @_;
 }
 
 # ---------------------------------------------------------------------------
+# and now the POD:
 
 =head1 NAME
 
@@ -137,14 +333,19 @@ sitescooper [options] [-sites sitename ...]
 sitescooper [options] [-name nm] [-levels n] [-storyurl regexp]
 	[-set sitefileparam value] url [...]
 
-Options: [-debug] [-refresh] [-config file]
+Options: [-debug] [-refresh] [-fullrefresh] [-config file]
 [-install dir] [-instapp app] [-dump] [-dumpprc] [-nowrite] [-nodates]
-[-quiet] [-admin cmd] [-nolinkrewrite] [-stdout-to file]
-[-keep-tmps] [-noheaders] [-nofooters] [-fromcache]
+[-quiet] [-admin cmd] [-nolinkrewrite] [-stdout-to file] [-badcache]
+[-keep-tmps] [-fromcache] [-noheaders] [-nofooters]
+[-outputtemplate file.tmpl]
+[-grep] [-profile file.nhp] [-profiles file.nhp file2.nhp ...]
 [-filename template] [-prctitle template] [-parallel] [-disc]
 [-limit numkbytes] [-maxlinks numlinks] [-maxstories numstories]
-[-text | -html | -mhtml | -doc | -isilo | -misilo | -richreader
-| -pipe fmt command]
+
+[-text | -html | -mhtml | -doc | -plucker | -mplucker | -isilo
+| -misilo | -richreader | -pipe fmt command]
+[-bw | -color] [-maxcolors n]
+[-cvtargs args_for_converter]
 
 =head1 DESCRIPTION
 
@@ -205,6 +406,12 @@ dedicated, sitescooper account is used instead.
 
 =item -refresh
 
+Refresh all links -- ignore the F<already_seen> file, do not diff pages,
+and always fetch links.  If a cached page is available, it will be
+used.
+
+=item -fullrefresh
+
 Refresh all links -- ignore the F<already_seen> file, do not diff pages,
 and always fetch links, even if they are available in the cache.
 
@@ -215,7 +422,7 @@ Read the configuration from B<file> instead of using the built-in one.
 =item -limit numkbytes
 
 Set the limit for output file size to B<numkbytes> kilobytes, instead of
-the default 200K.
+the default 200K. A limit of 0 means unlimited, any amount of output.
 
 =item -maxlinks numlinks
 
@@ -229,12 +436,12 @@ Stop retrieving web pages after B<numstories> stories have been retrieved.
 
 =item -install dir
 
-The directory to save PRC files to once they've been converted, in order
+The directory to save PDB files to once they've been converted, in order
 to have them installed to your Palm handheld.
 
 =item -instapp app
 
-The application to run to install PRC files onto your Palm, once they've
+The application to run to install PDB files onto your Palm, once they've
 been converted.
 
 =item -site sitename
@@ -250,6 +457,27 @@ provide multiple B<-site> arguments like so:
 Limit the run to multiple sites; an easier way to specify multiple sites
 than using the -site argument for each file.
 
+=item -grep
+
+Use James Brown's B<NewsHound> profile searching code.  Any sites that do not
+contain B<IgnoreProfiles: 1> will then be searched for the active profiles.
+Active profiles are loaded from the B<ProfileDir> specified in the sitescooper
+configuration file, or specified using the B<-profile> or B<-profiles>
+arguments.
+
+=item -profile file.nhp
+
+Limit the run to the site named in the B<file.nhp> argument.  Normally all
+available sites will be downloaded. To limit the run to 2 or more sites,
+provide multiple B<-profile> arguments like so:
+
+	-profile ntk.site -profile tbtf.site
+
+=item -profiles file.nhp [...]
+
+Limit the run to multiple sites; an easier way to specify multiple sites
+than using the -profile argument for each file.
+
 =item -name name
 
 When specifying a URL on the command-line, this provides the name that
@@ -291,6 +519,13 @@ called B<site_name>; in conjunction with the B<-dump> argument,
 it will output the path of this directory on standard output before
 exiting.
 
+=item -plucker
+
+Convert the page(s) downloaded into Plucker format (see
+http://plucker.gnu-designs.com/ ), on one big page.  The page(s) will be
+displayed with a table of contents (taken from the site if possible), followed
+by all the articles one after another.
+
 =item -isilo
 
 Convert the page(s) downloaded into iSilo format (see
@@ -347,16 +582,53 @@ with the name of the file containing the table-of-contents page. It's up
 to the conversion utility to follow the href links to the other files
 in that directory.
 
+=item -cvtargs
+
+Arguments for the conversion utility.
+
+=item -bw
+
+Indicate that the target can display only 2-bit images, black and white only.
+This is generally the default for iSilo and Plucker.
+
+=item -color
+
+Indicate that the target can display color images.
+
+=item -maxcolors n
+
+Indicate that the target supports a maximum of 'n' colors.  Plucker will
+display images better on some Palms if this is used.
+
+=item -fixlinks
+
+Rewrite links to external sites or unscooped pages as underlined text, to
+differentiate them from links to scooped pages.  This is the default behaviour
+for most formats apart from B<-plucker> or B<-mplucker>.
+
+=item -keeplinks
+
+Do not rewrite links to external sites or unscooped pages; leave them pointing
+outside the current scoop. However, links to other pages that are included in
+the current scoop, are rewritten to point to the scooped pages instead of the
+source URL. This is the default for Plucker (B<-plucker> or B<-mplucker>
+arguments).
+
+=item -nolinkrewrite
+
+Do not rewrite links on scooped documents -- leave them exactly as they are.
+This includes even links to other scooped pages.  See also B<-keeplinks>).
+
 =item -dump
 
 Output the page(s) downloaded directly to stdout in text or HTML format,
-instead of writing them to files and converting each one. This option
-implies B<-text>; to dump HTML, use B<-dump -html>.
+instead of writing them to files and converting each one. This option NO LONGER
+implies B<-text>, like it used to, so to dump text, use B<-dump -text>.
 
 =item -dumpprc
 
-Output the page(s) downloaded directly to stdout, in converted format as a
-PRC file, suitable for installation to a Palm handheld.
+Output the page(s) downloaded directly to stdout, in converted format as a PDB
+file (note: not PRC format!), suitable for installation to a Palm handheld.
 
 =item -nowrite
 
@@ -364,6 +636,12 @@ Test mode -- do not write to the cache or already_seen file, instead write
 what would be written normally to a directory called new_cache and a
 new_already_seen file. This is very handy when writing a new site file.
 
+=item -badcache
+
+Send some HTTP headers to bypass web caching proxy servers.  This is generally
+useful if a web caching proxy server somewhere between sitescooper and the
+target site is returning out-of-date files.
+
 =item -debug
 
 Enable debugging output. This output is in addition to the usual progress
@@ -419,11 +697,6 @@ If you wish to write a patch to support them, that'd be great.
 
 =back
 
-=item -nolinkrewrite
-
-Do not rewrite links on scooped documents -- leave them exactly as they
-are.
-
 =item -noheaders
 
 Do not attach the sitescooper header (URL, site name, and navigation
@@ -434,6 +707,12 @@ links) to each page.
 Do not attach the sitescooper footer ("copyright retained by original
 authors" blurb) to each page.
 
+=item -outputtemplate file.tmpl
+
+Read the output formatting template from the file B<file.tmpl>.  This overrides
+the settings of the B<-noheaders> and B<-nofooters> flags.
+See the OUTPUT TEMPLATES section below for details on this.
+
 =item -fromcache
 
 Do not perform any network access, retrieve everything from the cache or
@@ -488,10 +767,10 @@ The default filename template is B<YYYY_MM_DD_Site>.
 
 =item -prctitle template
 
-Change the format of the titles of the resulting PRC files. B<template>
+Change the format of the titles of the resulting PDB files. B<template>
 may contain the same keyword strings as B<-filename>.
 
-The default PRC title template is B<YYYY-Mon-DD: Site>.
+The default PDB title template is B<YYYY-Mon-DD: Site>.
 
 =item -nodates
 
@@ -499,13 +778,28 @@ Do not put the date in the installable file's filename. This allows you to
 automatically overwrite old files with new ones when you HotSync. It's
 a compatibility shortcut for B<-filename Site -prctitle "Site">.
 
-=item -parallel
+=item -preload preload_method
 
-Use the LWP::Parallel perl module, if available, to preload certain
-pages before the single-threaded sitescooper engine gets to them.
-This can speed up the scooping of several sites at once, but is
-more prone to crashes as the LWP::Parallel code is not as resilient
-as the traditional LWP code. This is off by default.
+Preload pages using the given preload method. Currently supported
+preload methods are:
+
+=over 4
+
+=item lwp
+
+Use the Perl LWP module to load pages. This is the default, and is
+single-threaded; in other words, each page needs to load fully before
+the next page can be requested.
+
+=item fork[n]
+
+Use a number of subprocesses running LWP requests to load pages.  This is
+multi-threaded, and several pages can be loaded at once; however you pay in
+costs of network bandwidth, CPU time and memory used. The optional B<n>
+argument instructs sitescooper to use that number of processes; the default
+B<n> is 4. This is only available on UNIX at the moment.
+
+=back
 
 =item -disc
 
@@ -527,6 +821,57 @@ it around.
 
 =back
 
+=head1 OUTPUT TEMPLATES
+
+You can control exactly what HTML or text is written to the output file using
+the B<-outputtemplate> argument.  This argument takes the name of a file, which
+is read and parsed to provide replacement templates for sitescooper.
+
+The file is read as a HTML- or XML-style tagged format; so for example the
+template for the main page in HTML format is read from between the
+B<&lt;htmlmainpage&gt;> and B<&lt;/htmlmainpage&gt;> tags. The templates
+that can be defined are as follows:
+
+=over 4
+
+=item B<htmlmainpage>
+
+The main page, in HTML format; this is used when the -html output format, or
+one based on it (such as -plucker or -isilo), is used.  It is also used for the
+-mhtml format's main (top-level) page.
+
+=item B<htmlsubpage>
+
+Sub-page, in HTML format; this is used for the -mhtml output format's sub
+pages, ie. pages other than the top-level one.
+
+=item B<htmlstory>
+
+The snippet of HTML encapsulating each story. This is included for each
+piece of snarfed text, in all HTML files.
+
+=item B<textmainpage>
+
+The main page, in text format; this is used when the -text output format, or
+one based on it (such as -doc), is used.
+
+=item B<textsubpage>
+
+Sub-page, in text format; this is currently unused.
+
+=item B<textstory>
+
+The snippet of text encapsulating each story. This is included for each
+piece of snarfed text, in all text-format or DOC-format files.
+
+=back
+
+A sample template file is provided in the file C<default_templates.html>; this
+may have been installed in the sitescooper install directory,
+/usr/share/sitescooper, or /usr/local/share/sitescooper.  Note that the actual
+templates used are not loaded from this file; instead they are incorporated
+inside the sitescooper script, so changing this file will have no effect.
+
 =head1 INSTALLATION
 
 To install, edit the script and change the #! line. You may also need to
@@ -547,6 +892,11 @@ To snarf the ever-cutting NTKnow newsletter.
 To snarf NTKnow, ignoring any previously-read text, and producing HTML
 output.
 
+	sitescooper.pl -refresh -html -site site_samples/tech/ntk.site
+
+To snarf NTKnow using the site file provided with the main distribution,
+producing HTML output.
+
 =head1 ENVIRONMENT
 
 B<sitescooper> makes use of the C<$http_proxy> environment variable, if it
@@ -600,20 +950,16 @@ you do not need to install it separately.
 
 =head1 COREQUISITES
 
-C<LWP::Parallel> will be used if available.  C<Win32::TieRegistry>, if
-running on a Win32 platform, to find the Pilot Desktop software's
-installation directory. C<Algorithm::Diff> to support diffing sites
-without running an external B<diff> application (this is required on Mac
-systems).
+C<Win32::TieRegistry> will be used, if running on a Win32 platform, to find the
+Pilot Desktop software's installation directory. C<Algorithm::Diff> to support
+diffing sites without running an external B<diff> application (this is required
+on Mac systems).
 
 =head1 README
 
 Sitescooper downloads news stories from the web and converts them to Palm
 handheld iSilo, DOC or text format for later reading on-the-move.  Site
 files and full documentation can be found at
-http://sitescooper.cx/ .
+http://sitescooper.org/ .
 
 =cut
-
-#---------------------------------------------------------------------------
-
